"use strict";

var _react = _interopRequireDefault(require("react"));
var _recharts = require("recharts");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }
/******************************************************************************************************************
 * BarChart React Component that displays a bar chart with customizable options.
 * 
 * @param {Array<string>} labels - An array of labels for the data points on the x-axis.
 * @param {Array<number>} data - An array of numerical data values corresponding to the labels.
 * @param {string} barColor -  The color code in hex of the bars in the chart.
 * @param {boolean} showCartesianGrid - Whether to show the Cartesian grid lines.
 * @param {boolean} showTooltip - Whether to show tooltips on hover.
 * @param {number} height - The height of the chart container.
 * 
 * @returns {JSX.Element} A React component that renders a bar chart with the provided data and options.
 *****************************************************************************************************************/
var _BarChart = function _BarChart(_ref) {
  var labels = _ref.labels,
    data = _ref.data,
    barColor = _ref.barColor,
    showCartesianGrid = _ref.showCartesianGrid,
    showTooltip = _ref.showTooltip,
    width = _ref.width,
    height = _ref.height;
  var GRAPH_DATA = labels.map(function (lable, index) {
    var data_length = data.length;
    return {
      "name": lable,
      "value": index <= data_length - 1 ? data[index] : 0 // return 0, if value is not present in corresponding to respected label
    };
  });
  return /*#__PURE__*/_react["default"].createElement("div", {
    className: "w-full md:w-3/4 lg:w-1/2 xl:w-1/3 mx-auto"
  }, " ", /*#__PURE__*/_react["default"].createElement(_recharts.BarChart, {
    width: "100%",
    height: height,
    data: GRAPH_DATA
  }, showCartesianGrid && /*#__PURE__*/_react["default"].createElement(_recharts.CartesianGrid, {
    strokeDasharray: "3 3"
  }), /*#__PURE__*/_react["default"].createElement(_recharts.XAxis, {
    dataKey: "name"
  }), /*#__PURE__*/_react["default"].createElement(_recharts.YAxis, null), showTooltip && /*#__PURE__*/_react["default"].createElement(_recharts.Tooltip, null), /*#__PURE__*/_react["default"].createElement(_recharts.Bar, {
    dataKey: "value",
    fill: barColor
  })));
};
_BarChart.defaultProps = {
  labels: ['Label1', 'Label2', 'Label3', 'Label4', 'Label5'],
  data: [67, 98, 24, 99, 53],
  barColor: "#0000FF",
  showCartesianGrid: false,
  showTooltip: false,
  height: 250
};
module.exports = _BarChart;